/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2009 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                                          *
*********************************************************************************
* Id: fxmoviemanager.cpp,   v 2.2                    2008/01/01                 *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <fx.h>
#include <xincs.h>
#include <fxkeys.h>

#include "fxmoviemanager.h"
#include "icons.h"
#include "OperationsDialog.h"
#include "PropertiesDialog.h"
#include "MimeTypeDialog.h"

#ifndef WIN32
#include <unistd.h>
#endif

#define CLOCKTIMER      1000000000


static const FXchar sourcefiles[]=
	"All Files (*)"
	"\nmpeg (*.mpeg,*.MPEG,*.mpg,*.MPG,*.mp4,*.MP4)"
	"\navi (*.avi,*.AVI)"
	"\nwindows media (*.wmv,*.WMV,*.wma,*.WMA,*.asf,*.ASF)"
	"\nquicktime (*.mov,*.MOV,*.qt,*.QT,*.mod,*.MOD)"
	"\nmobile (*.3gp,*.3GP,*.3gp2,*.3GP2)"
	"\nreal media (*.rm,*.RM)";


FXDEFMAP(FXMovieManager) FXMovieManagerMap[] = {
	//________Message_Type_____________________________ID______________________Message_Handler__________
	// buttons
  	FXMAPFUNC(SEL_TIMEOUT,           	FXMovieManager::ID_CLOCKTIME,   FXMovieManager::onClock),
	FXMAPFUNC(SEL_COMMAND,      		FXMovieManager::ID_QUIT,       	FXMovieManager::onCmdQuit),
	FXMAPFUNC(SEL_SIGNAL,        		FXMovieManager::ID_QUIT,       	FXMovieManager::onCmdQuit),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_FILE,       	FXMovieManager::onCmdFile),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_LOOP,       	FXMovieManager::onCmdLoop),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_FULL,       	FXMovieManager::onCmdFull),

	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_AUDIO,		FXMovieManager::onCmdAudio),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_AUDIO,		FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_PLAY,       	FXMovieManager::onCmdPlay),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_PLAY,		FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_PAUSE,      	FXMovieManager::onCmdPause),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_PAUSE,		FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_STOP,       	FXMovieManager::onCmdStop),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_STOP,		FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_DROP,       	FXMovieManager::onCmdDrop),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_DROP,		FXMovieManager::onUpdSelectedList),

  	FXMAPFUNCS(SEL_UPDATE,           	FXMovieManager::ID_SIZE_1,     	FXMovieManager::ID_SIZE_9, 	FXMovieManager::onUpdSizeSwitch),
  	FXMAPFUNCS(SEL_COMMAND,          	FXMovieManager::ID_SIZE_1,     	FXMovieManager::ID_SIZE_9, 	FXMovieManager::onCmdSizeSwitch),
  	FXMAPFUNCS(SEL_UPDATE,           	FXMovieManager::ID_VIDEO_1,    	FXMovieManager::ID_VIDEO_9, FXMovieManager::onUpdVideoSwitch),
  	FXMAPFUNCS(SEL_COMMAND,          	FXMovieManager::ID_VIDEO_1,    	FXMovieManager::ID_VIDEO_9, FXMovieManager::onCmdVideoSwitch),
 	// play list 
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_PUTBACK,    	FXMovieManager::onCmdPutBack),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_MOVEUP,     	FXMovieManager::onCmdMoveUp),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_MOVEDOWN,   	FXMovieManager::onCmdMoveDown),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_APPEND,     	FXMovieManager::onCmdAppend),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_INSERT,     	FXMovieManager::onCmdInsert),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_REPLACE,    	FXMovieManager::onCmdReplace),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_SELECTALL,  	FXMovieManager::onCmdSelectAll),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_DELETE,     	FXMovieManager::onCmdDelete),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_CLEAR,      	FXMovieManager::onCmdClear),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_LIST,   		FXMovieManager::onListRightMouse),
	// directory list
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_DIRECTORYLIST,FXMovieManager::onCmdDirectory),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_DIRECTORYLIST,FXMovieManager::onDirListPopup),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_NEWDIR,		FXMovieManager::onCmdNewDir),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_NEWDIR,		FXMovieManager::onUpdNewDir),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_DIRDELETE,	FXMovieManager::onCmdDirDelete),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_DIRDELETE,	FXMovieManager::onUpdNewDir),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_DIRRENAME,	FXMovieManager::onCmdDirRename),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_DIRRENAME,	FXMovieManager::onUpdNewDir),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_UPDIRECTORY,	FXMovieManager::onCmdUpDirectory),
	// file list
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_FILELIST,	FXMovieManager::onFileListPopup),
	FXMAPFUNC(SEL_DOUBLECLICKED, 		FXMovieManager::ID_FILELIST,   	FXMovieManager::onCmdFileList),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILECOPY,	FXMovieManager::onCmdFileCopy),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILECOPY,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILESYMLINK,	FXMovieManager::onCmdFileSymlink),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILESYMLINK,	FXMovieManager::onUpdSelectedFile),
   	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILERENAME,	FXMovieManager::onCmdFileRename),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILERENAME,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILEDELETE,	FXMovieManager::onCmdFileDelete),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILEDELETE,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILEPLAY,	FXMovieManager::onCmdFilePlay),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILEPLAY,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILEPAUSE,	FXMovieManager::onCmdFilePause),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILEPAUSE,	FXMovieManager::onUpdSelectedFile),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_FILESTOP,   	FXMovieManager::onCmdFileStop),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILESTOP,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FILEPREVIEW,	FXMovieManager::onCmdFilePreview),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILEPREVIEW, FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_FORCEFILEPREVIEW,FXMovieManager::onCmdForceFilePreview),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FORCEFILEPREVIEW,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_WIDESCREEN,FXMovieManager::onCmdWideScreen),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_WIDESCREEN,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_INCFILEPREVIEW,FXMovieManager::onCmdIncFilePreview),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_INCFILEPREVIEW,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_DECFILEPREVIEW,FXMovieManager::onCmdDecFilePreview),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_DECFILEPREVIEW,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_CLEARPREVIEW,FXMovieManager::onCmdClearPreview),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_TERMINAL,	FXMovieManager::onCmdTerminal),
	// properties 
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_PROPERTIES,	FXMovieManager::onCmdProperties),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_CREATED,FXMovieManager::onUpdCreateTime),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_MODIFIED,FXMovieManager::onUpdModifyTime),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_ACCESSED,FXMovieManager::onUpdAccessTime),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_TYPE,	FXMovieManager::onUpdFileType),
	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_MIMETYPE,FXMovieManager::onUpdFileMimeType),
	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_COMMAND,FXMovieManager::onUpdFileCommand),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_LOCATION,FXMovieManager::onUpdFileLocation),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_SIZE,	FXMovieManager::onUpdFileSize),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_FILE_DESC,	FXMovieManager::onUpdFileDesc),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_VIDEO_ASPECT,FXMovieManager::onUpdMovieAspect),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_AUDIO_FORMAT,FXMovieManager::onUpdAudioFormat),
	// extensions association 
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_MIMETYPE,	FXMovieManager::onCmdMimeType),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_OPEN,		FXMovieManager::onUpdItemFound),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_OPEN,		FXMovieManager::onCmdOpen),
  	FXMAPFUNC(SEL_UPDATE,				FXMovieManager::ID_OPENWITH,	FXMovieManager::onUpdItemFound),
  	FXMAPFUNC(SEL_COMMAND,				FXMovieManager::ID_OPENWITH,	FXMovieManager::onCmdOpenWith),
};

FXIMPLEMENT(FXMovieManager, FXMainWindow, FXMovieManagerMap, ARRAYNUMBER(FXMovieManagerMap))

FXMovieManager::FXMovieManager(FXApp *a)
	:FXMainWindow(a, "F X M o v i e M a n a g e r", NULL, NULL, DECOR_TITLE|DECOR_MINIMIZE|DECOR_MAXIMIZE|DECOR_CLOSE|DECOR_BORDER|DECOR_SHRINKABLE|DECOR_STRETCHABLE|DECOR_MENU, 0, 0, 800, 54) {

	// set icon on the main window
	logoicon=new FXPNGIcon(getApp(),fxmmlogo);
	setIcon(logoicon);

	themeSelection();
	languageSelection();

	// popup list menu icons
    m_upicon=new FXGIFIcon(getApp(),m_up);
    m_downicon=new FXGIFIcon(getApp(),m_down);
    m_appendicon=new FXGIFIcon(getApp(),m_append);
  	m_cancelicon=new FXGIFIcon(getApp(),m_cancel);
  	m_accepticon=new FXGIFIcon(getApp(),m_accept);
	// popup file menu icons
	m_propicon=new FXGIFIcon(getApp(),m_properties);
    m_copyicon=new FXGIFIcon(getApp(),m_copy);
    m_moveicon=new FXGIFIcon(getApp(),m_move);
    m_renameicon=new FXGIFIcon(getApp(),m_rename);
    m_deleteicon=new FXGIFIcon(getApp(),m_delete);
    m_refreshicon=new FXGIFIcon(getApp(),m_refresh);
    m_renamediricon=new FXGIFIcon(getApp(),m_renamedir);
    m_showhiddenicon=new FXGIFIcon(getApp(),m_showhidden);

	// menubar
	menubar = new FXMenuBar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	quitbutton = new FXButton(menubar,quitbuttontext,quiticon,this,ID_QUIT,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	openbutton = new FXButton(menubar,openbuttontext,openicon,this,ID_FILE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	audiobutton = new FXToggleButton(menubar,audiobuttontext1,audiobuttontext2,audioicon,audioicon,this,ID_AUDIO,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	dropbutton = new FXToggleButton(menubar,dropbuttontext1,dropbuttontext2,dropicon,dropicon,this,ID_DROP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	stopbutton = new FXButton(menubar,stopbuttontext,stopicon,this,ID_STOP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	pausebutton = new FXButton(menubar,pausebuttontext,pauseicon,this,ID_PAUSE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	playbutton = new FXButton(menubar,playbuttontext,playicon,this,ID_PLAY,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	loopbutton = new FXToggleButton(menubar,loopbuttontext1,loopbuttontext2,loopicon,loopicon,this,ID_LOOP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	zoombutton = new FXToggleButton(menubar,zoombuttontext1,zoombuttontext2,videozoomicon,videozoomicon,this,ID_FULL,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);

	videosizemenu = new FXMenuPane(this);
    videosizebutton = new FXMenuButton(menubar,sizebuttontext,videosizeicon,videosizemenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
	videosizebutton->showMenu(FALSE);
   	new FXMenuRadio(videosizemenu,"720x576",this,ID_SIZE_1);
  	new FXMenuRadio(videosizemenu,"640x480",this,ID_SIZE_2);
  	new FXMenuRadio(videosizemenu,"500x284",this,ID_SIZE_3);
  	new FXMenuRadio(videosizemenu,"480x576",this,ID_SIZE_4);
  	new FXMenuRadio(videosizemenu,"480x480",this,ID_SIZE_5);
  	new FXMenuRadio(videosizemenu,"352x288",this,ID_SIZE_6);
  	new FXMenuRadio(videosizemenu,"352x240",this,ID_SIZE_7);
  	new FXMenuRadio(videosizemenu,"320x240",this,ID_SIZE_8);
  	new FXMenuRadio(videosizemenu,"FILESET",this,ID_SIZE_9);

	videooutmenu = new FXMenuPane(this);
    videooutbutton = new FXMenuButton(menubar,outputbuttontext,videoouticon,videooutmenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
	videooutbutton->showMenu(FALSE);
   	new FXMenuRadio(videooutmenu,"X11 ",this,ID_VIDEO_1);
  	new FXMenuRadio(videooutmenu,"XV  ",this,ID_VIDEO_2);
  	new FXMenuRadio(videooutmenu,"GL2 ",this,ID_VIDEO_3);
  	new FXMenuRadio(videooutmenu,"SDL ",this,ID_VIDEO_4);
  	new FXMenuRadio(videooutmenu,"DGA ",this,ID_VIDEO_5);
  	new FXMenuRadio(videooutmenu,"XVID",this,ID_VIDEO_6);
  	new FXMenuRadio(videooutmenu,"JPEG",this,ID_VIDEO_7);
  	new FXMenuRadio(videooutmenu,"PNG ",this,ID_VIDEO_8);
  	new FXMenuRadio(videooutmenu,"NULL",this,ID_VIDEO_9);


	FXVerticalFrame *speedframe=new FXVerticalFrame(menubar,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
	FXHorizontalFrame *seekframe=new FXHorizontalFrame(speedframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	FXHorizontalFrame *inspeedframe=new FXHorizontalFrame(speedframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);

	new FXLabel(seekframe,"S",NULL);
	seekposition1=new FXTextField(seekframe,2,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	seekposition2=new FXTextField(seekframe,2,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	seekposition3=new FXTextField(seekframe,2,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	seekposition1->setText("00");
	seekposition2->setText("00");
	seekposition3->setText("00");

	new FXLabel(inspeedframe,"s",NULL);
  	speedslider=new FXSlider(inspeedframe,NULL,0,LAYOUT_TOP|LAYOUT_FILL_X|LAYOUT_FIX_HEIGHT|SLIDER_HORIZONTAL|SLIDER_INSIDE_BAR|SLIDER_TICKS_BOTTOM,0,0,200,20);
  	speedslider->setRange(2,20);
	speedslider->setValue(10);
	speedslider->setIncrement(1);

	FXVerticalFrame *volumeframe=new FXVerticalFrame(menubar,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
	FXHorizontalFrame *endframe=new FXHorizontalFrame(volumeframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	FXHorizontalFrame *involumeframe=new FXHorizontalFrame(volumeframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);

	new FXLabel(endframe,"L",NULL);
	endposition1=new FXTextField(endframe,2,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	endposition2=new FXTextField(endframe,2,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	endposition3=new FXTextField(endframe,2,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	endposition1->setText("01");
	endposition2->setText("00");
	endposition3->setText("00");

	new FXLabel(involumeframe,"v",NULL);
  	volumeslider=new FXSlider(involumeframe,NULL,0,LAYOUT_TOP|LAYOUT_FILL_X|LAYOUT_FIX_HEIGHT|SLIDER_HORIZONTAL|SLIDER_INSIDE_BAR|SLIDER_TICKS_BOTTOM,0,0,200,20);
  	volumeslider->setRange(0,100);
	volumeslider->setValue(50);
	volumeslider->setIncrement(5);


	// Splitter
	splitter1=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);

	// Make simplelist
	listframe=new FXHorizontalFrame(splitter1,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
  	simplelist = new FXList(listframe,this,ID_LIST,LIST_EXTENDEDSELECT|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL);


	// new FXButton(menubar,"FileList",listicon,listframe,FXWindow::ID_TOGGLESHOWN,BUTTON_TOOLBAR|FRAME_RAISED|ICON_AFTER_TEXT);
	hidebutton = new FXToggleButton(menubar,hidebuttontext1,hidebuttontext2,hideicon,hideicon,this,ID_PUTBACK,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);

	new FXButton(menubar,confbuttontext,logoicon,this,ID_MIMETYPE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);

	// right list buttons
	listbuttonframe=new FXVerticalFrame(listframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(listbuttonframe,upbuttontext,upicon,this,FXMovieManager::ID_MOVEUP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,downbuttontext,downicon,this,FXMovieManager::ID_MOVEDOWN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,allbuttontext1,showicon,this,FXMovieManager::ID_SELECTALL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,clearbuttontext,deleteicon,this,FXMovieManager::ID_CLEAR,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	// Right mouse popup
	popupmenu = new FXMenuPane(this);
	playlistlabel = new FXLabel(popupmenu,"Play List");
	playlistlabel->setTextColor(FXRGB(150,0,0));
	new FXMenuCommand(popupmenu,"Move Up",m_upicon,this,FXMovieManager::ID_MOVEUP);
	new FXMenuCommand(popupmenu,"Move Down",m_downicon,this,FXMovieManager::ID_MOVEDOWN);
	new FXMenuSeparator(popupmenu);
	new FXMenuCommand(popupmenu,"Select All",m_accepticon,this,FXMovieManager::ID_SELECTALL);
	new FXMenuCommand(popupmenu,"Cancel All",m_cancelicon,this,FXMovieManager::ID_CLEAR);
	new FXMenuSeparator(popupmenu);
	new FXMenuCommand(popupmenu,"Append Items",m_appendicon,this,FXMovieManager::ID_APPEND);
//	new FXMenuCommand(popupmenu,"Insert",NULL,this,FXMovieManager::ID_INSERT);
//	new FXMenuCommand(popupmenu,"Replace",NULL,this,FXMovieManager::ID_REPLACE);
	new FXMenuCommand(popupmenu,"Cancel Item",m_cancelicon,this,FXMovieManager::ID_DELETE);


	// Make file associations object; shared between FXFileList and FXDirList
	associations=new FXFileDict(getApp());

	// file box
  	splitter2=new FXSplitter(splitter1,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_HORIZONTAL);
  	dirframe=new FXVerticalFrame(splitter2,LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,180,0, 0,0,0,0,0,0);
  	filebuttonframe=new FXHorizontalFrame(splitter2,LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);
  	fileframe=new FXVerticalFrame(filebuttonframe,LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);

  	// Folder List
  	dirlist=new FXDirList(dirframe,this,ID_DIRECTORYLIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_RIGHT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC);
  	dirlist->setAssociations(associations);
  	dirlist->dropEnable();


	// File list
	filelist=new FXFileList(fileframe,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_BIG_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
	filelist->setAssociations(associations);
  	filelist->dropEnable();


  	// MimeType panel
  	mimetype=new MimeTypeDialog(this);

  	// Properties panel
  	properties=new PropertiesDialog(this);

  	// Status bar
  	statusbar=new FXStatusBar(dirframe,LAYOUT_SIDE_BOTTOM|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);

  	// Clock on status bar with same colour
  	clock=new FXTextField(statusbar,8,NULL,0,FRAME_SUNKEN|JUSTIFY_RIGHT|LAYOUT_RIGHT|LAYOUT_CENTER_Y|TEXTFIELD_READONLY,0,0,0,0,2,2,1,1);
  	clock->setBackColor(statusbar->getBackColor());


	vbuttonframe=new FXVerticalFrame(filebuttonframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(vbuttonframe,upbuttontext,upicon,this,ID_UPDIRECTORY,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	// seek value for movie preview
    seekspinner=new FXRealSpinner(vbuttonframe,2,NULL,0,REALSPIN_CYCLIC|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
    seekspinner->setRange(0.1,3.1);
    seekspinner->setValue(0.1);
    seekspinner->setIncrement(0.1);

  	selectbutton=new FXToggleButton(vbuttonframe,allbuttontext1,allbuttontext2,showicon,hiddenicon,filelist,FXFileList::ID_SELECT_INVERSE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,createbuttontext,createicon,this,ID_FILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,recreatebuttontext,recreateicon,this,ID_FORCEFILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
  	widebutton=new FXToggleButton(vbuttonframe,widebuttontext1,widebuttontext2,videoicon,videoicon,this,ID_WIDESCREEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,deletebuttontext,deletehiddenicon,this,ID_CLEARPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	sizeframe=new FXHorizontalFrame(vbuttonframe,LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(sizeframe,increasebuttontext,increaseicon,this,ID_INCFILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_LEFT);
	new FXButton(sizeframe,decreasebuttontext,decreaseicon,this,ID_DECFILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_RIGHT);

	new FXMenuSeparator(vbuttonframe);

	new FXButton(vbuttonframe,stopbuttontext,stopicon,this,ID_FILESTOP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,pausebuttontext,pauseicon,this,ID_FILEPAUSE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,playbuttontext,playicon,this,ID_FILEPLAY,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	switchframe=new FXHorizontalFrame(vbuttonframe,LAYOUT_FILL_X|LAYOUT_BOTTOM,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(switchframe,detlisttext,detlisticon,filelist,FXFileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_LEFT);
	new FXButton(switchframe,icnlisttext,icnlisticon,filelist,FXFileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_RIGHT);


  	// Add accelerators into the table
  	//				 addAccel(		 FXHotKey		  target	(FXSelector seldn, FXSelector selup)
  	getAccelTable()->addAccel(MKUINT(KEY_BackSpace,0),this,FXSEL(SEL_COMMAND,ID_UPDIRECTORY));	
  	getAccelTable()->addAccel(MKUINT(KEY_Delete,0),this,FXSEL(SEL_COMMAND,ID_FILEDELETE));	
	
  	getAccelTable()->addAccel(MKUINT(KEY_F1,0),this,FXSEL(SEL_COMMAND,ID_MIMETYPE));
  	getAccelTable()->addAccel(MKUINT(KEY_F2,0),filelist,FXSEL(SEL_COMMAND,FXFileList::ID_SELECT_INVERSE));
  	getAccelTable()->addAccel(MKUINT(KEY_F3,0),this,FXSEL(SEL_COMMAND,ID_FILEPREVIEW));
  	getAccelTable()->addAccel(MKUINT(KEY_F4,0),this,FXSEL(SEL_COMMAND,ID_FORCEFILEPREVIEW));
  	getAccelTable()->addAccel(MKUINT(KEY_F5,0),this,FXSEL(SEL_COMMAND,ID_INCFILEPREVIEW));
  	getAccelTable()->addAccel(MKUINT(KEY_F6,0),this,FXSEL(SEL_COMMAND,ID_DECFILEPREVIEW));
  	getAccelTable()->addAccel(MKUINT(KEY_F7,0),filelist,FXSEL(SEL_COMMAND,FXFileList::ID_SHOW_BIG_ICONS));
  	getAccelTable()->addAccel(MKUINT(KEY_F8,0),filelist,FXSEL(SEL_COMMAND,FXFileList::ID_SHOW_DETAILS));
 	// OPERATIONS DIALOG
  	getAccelTable()->addAccel(MKUINT(KEY_c,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILECOPY));
  	getAccelTable()->addAccel(MKUINT(KEY_C,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILECOPY));
	getAccelTable()->addAccel(MKUINT(KEY_r,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILERENAME));
	getAccelTable()->addAccel(MKUINT(KEY_R,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILERENAME));
	getAccelTable()->addAccel(MKUINT(KEY_s,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESYMLINK));
	getAccelTable()->addAccel(MKUINT(KEY_S,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESYMLINK));
	// MPLAYER
	getAccelTable()->addAccel(MKUINT(KEY_z,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPLAY));
	getAccelTable()->addAccel(MKUINT(KEY_Z,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPLAY));
  	getAccelTable()->addAccel(MKUINT(KEY_a,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPAUSE));	
  	getAccelTable()->addAccel(MKUINT(KEY_A,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPAUSE));
   	getAccelTable()->addAccel(MKUINT(KEY_q,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESTOP));	
	getAccelTable()->addAccel(MKUINT(KEY_Q,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESTOP));


	// Progress bar
  	progressframe=new FXHorizontalFrame(fileframe,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
    progressbar=new FXProgressBar(progressframe,NULL,0,PROGRESSBAR_HORIZONTAL|PROGRESSBAR_PERCENTAGE|PROGRESSBAR_NORMAL|LAYOUT_FILL_X);


  	// Make a tool tip
  	new FXToolTip(getApp(),0);

	// inithialize some parameters
	s_command = "mplayer -slave -idle -quiet -ontop -input file=/tmp/.fxmm/fifo ";
	terminal = "xterm -bg black -fg grey70 -geometry 120x40";
	language = "en";
	isrunning = FALSE;
	widescreen = FALSE;
	imgw=80; imgh=64;
	system ("test -d /tmp/.fxmm || mkdir /tmp/.fxmm");
	system ("test -p /tmp/.fxmm/fifo || mkfifo /tmp/.fxmm/fifo");
  	FXString command="mplayer -vo help";
  	system (command.text());  // initialize MPlayer
}

FXMovieManager::~FXMovieManager() {

	delete audioicon;
	delete createicon; 
	delete decreaseicon; 
	delete deleteicon; 
	delete deletehiddenicon; 
	delete downicon;
	delete dropicon; 
	delete hiddenicon;
	delete hideicon; 
	delete increaseicon; 
	delete loopicon;
	delete openicon; 
	delete pauseicon;
	delete playicon;
	delete quiticon;
	delete recreateicon; 
	delete showicon; 
	delete stopicon;
	delete upicon;
	delete videoicon;
	delete videozoomicon;
	delete videosizeicon;
	delete videoouticon;
	delete icnlisticon;
	delete detlisticon;

	delete m_upicon;
	delete m_downicon;
	delete m_appendicon;
	delete m_accepticon;
	delete m_cancelicon;

	delete m_copyicon;
	delete m_moveicon;
	delete m_renameicon;
	delete m_deleteicon;
  	getApp()->removeTimeout(this,ID_CLOCKTIME);
}


/*********************** UPDATE CLOCK **************************/


// Update clock
long FXMovieManager::onClock(FXObject*,FXSelector,void*){
#ifdef FOX_17
  FXTime now=FXThread::time();
  // show time
  clock->setText(FXSystem::localTime(tr("%H:%M:%S"),now));
  // tooltip date
  clock->setTipText(FXSystem::localTime(tr("%A %d %B %Y"),now));
  getApp()->addTimeout(this,ID_CLOCKTIME,CLOCKTIMER);
#endif
  return 0;
  }


/*********************** ROUTINES ******************************/


// Load file
FXbool FXMovieManager::loadfile(const FXString& filename){
	FXString ext=FXPath::extension(filename);

	if(comparecase(ext,"mpeg")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MPEG")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mpg")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MPG")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mp4")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MP4")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"avi")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"AVI")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"wmv")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"WMV")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"wma")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"WMA")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"asf")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"ASF")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mov")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MOV")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mod")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MOD")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"qt")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"QT")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"rm")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"RM")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3gp")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3GP")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3gp2")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3GP2")==0){
		simplelist->appendItem(filename);
	}
	else {
		FXMessageBox::error(this,MBOX_OK,"Error Loading Movie","Unsupported type: %s",ext.text());
		return FALSE;
	}
  return TRUE;
}


// Load imagemovie on the list for preview
FXbool FXMovieManager::previewListMovie(const FXString& filename, FXint i){
    FXString imagename=filename;
    //printf("the current directory is: %s\n", filename.text());

#ifdef FOX_16
    FXIcon *tempicon=NULL;
    tempicon=new FXIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);
#endif
#ifdef FOX_17
    FXJPGIcon *tempicon=NULL;
    tempicon=new FXJPGIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);
#endif

    if (tempicon){

   	FXFileStream stream;
   	if (stream.open(imagename,FXStreamLoad)){
		getApp()->beginWaitCursor();
		tempicon->loadPixels(stream);
		stream.close();

		tempicon->scale(80,64,75); 
        	tempicon->create();

		simplelist->setItemIcon(i,tempicon);

		getApp()->endWaitCursor();

		return TRUE;
	}
    }
    return FALSE;
}


// get selected movies from file dialog
void FXMovieManager::getFiledialogSelection(){
	FXString rootname, imagename;

	currentdir = dirlist->getDirectory();

	FXString* files=FXFileDialog::getOpenFilenames(this,"Select the Movies to Append",currentdir,sourcefiles,1);
	if(files){
		for(int i=0; !files[i].empty(); i++){
			filename = files[i];
			loadfile(filename);

  			rootname=FXPath::name(FXPath::stripExtension(filename));
			imagename=FXPath::enquote(getDirectory())+"/."+rootname+"00000001/00000001.jpg";
    			//printf("the imagename is: %s\n", imagename.text());
        		FXint numitems = simplelist->getNumItems();
			//printf("the itemnumber is: %d\n", numitems-1);
  			previewListMovie(imagename, numitems-1);
		}
		// clean up files
		delete [] files;
	}
	selectAll();
	return;
}


// get selected movies from file list
void FXMovieManager::getFilelistSelection() {
  // load one file at a time
  FXint numitems = simplelist->getNumItems();

  FXString ffile,rootname,imagename;
  for(FXint i=0; i<filelist->getNumItems(); i++){
    	if(filelist->isItemSelected(i)){
        	ffile=filelist->getItemFilename(i);
        	if(ffile=="..") continue;

  		rootname=FXPath::stripExtension(ffile);
  		imagename=FXPath::enquote(getDirectory())+"/."+rootname+"00000001/00000001.jpg";
    		//printf("the imagename is: %s\n", imagename.text());
		previewListMovie(imagename, numitems-1);
		//printf("the numitems is: %d\n", numitems-1);
	}
  }
  return;	
}


// load theme 
FXbool FXMovieManager::themeSelection() {
  theme=getApp()->reg().readStringEntry("SETTINGS","theme");

  theme_fore=getApp()->reg().readColorEntry("SETTINGS","forecolor");
  theme_base=getApp()->reg().readColorEntry("SETTINGS","basecolor");
  theme_back=getApp()->reg().readColorEntry("SETTINGS","backcolor");
  theme_menufore=getApp()->reg().readColorEntry("SETTINGS","selmenutextcolor");
  theme_menuback=getApp()->reg().readColorEntry("SETTINGS","selmenubackcolor");
  theme_selfore=getApp()->reg().readColorEntry("SETTINGS","selforecolor");
  theme_selback=getApp()->reg().readColorEntry("SETTINGS","selbackcolor");

  getApp()->setForeColor(theme_fore);
  getApp()->setBaseColor(theme_base);
  getApp()->setBackColor(theme_back);
  getApp()->setSelMenuTextColor(theme_menufore);
  getApp()->setSelMenuBackColor(theme_menuback);
  getApp()->setSelforeColor(theme_selfore);
  getApp()->setSelbackColor(theme_selback);


  if(theme=="dark"||theme=="gentle"){
	audioicon=new FXGIFIcon(getApp(),audio_32x32);
	createicon=new FXGIFIcon(getApp(),create_32x32); 
	deleteicon=new FXGIFIcon(getApp(),delete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),deletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),down_32x32);
	dropicon=new FXGIFIcon(getApp(),drop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),hidden_32x32);
	hideicon=new FXGIFIcon(getApp(),hide_32x32); 
	loopicon=new FXGIFIcon(getApp(),loop_32x32);
	openicon=new FXGIFIcon(getApp(),open_32x32); 
	pauseicon=new FXGIFIcon(getApp(),pause_32x32);
	playicon=new FXGIFIcon(getApp(),play_32x32);
	quiticon=new FXGIFIcon(getApp(),quit_32x32);
	recreateicon=new FXGIFIcon(getApp(),recreate_32x32); 
	showicon=new FXGIFIcon(getApp(),show_32x32); 
	stopicon=new FXGIFIcon(getApp(),stop_32x32);
	upicon=new FXGIFIcon(getApp(),up_32x32);
	videoicon=new FXGIFIcon(getApp(),video_32x32);
	videoouticon=new FXGIFIcon(getApp(),videoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),videosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),videozoom_32x32);
	decreaseicon=new FXGIFIcon(getApp(),decrease_16x32); 
	increaseicon=new FXGIFIcon(getApp(),increase_16x32); 
	icnlisticon=new FXGIFIcon(getApp(),icnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),detlist_16x32);
  	return TRUE;
  }else if(theme=="shine"||theme=="fog"){
	audioicon=new FXGIFIcon(getApp(),raudio_32x32);
	createicon=new FXGIFIcon(getApp(),rcreate_32x32); 
	deleteicon=new FXGIFIcon(getApp(),rdelete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),rdeletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),rdown_32x32);
	dropicon=new FXGIFIcon(getApp(),rdrop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),rhidden_32x32);
	hideicon=new FXGIFIcon(getApp(),rhide_32x32); 
	loopicon=new FXGIFIcon(getApp(),rloop_32x32);
	openicon=new FXGIFIcon(getApp(),ropen_32x32); 
	pauseicon=new FXGIFIcon(getApp(),rpause_32x32);
	playicon=new FXGIFIcon(getApp(),rplay_32x32);
	quiticon=new FXGIFIcon(getApp(),rquit_32x32);
	recreateicon=new FXGIFIcon(getApp(),rrecreate_32x32); 
	showicon=new FXGIFIcon(getApp(),rshow_32x32); 
	stopicon=new FXGIFIcon(getApp(),rstop_32x32);
	upicon=new FXGIFIcon(getApp(),rup_32x32);
	videoicon=new FXGIFIcon(getApp(),rvideo_32x32);
	videoouticon=new FXGIFIcon(getApp(),rvideoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),rvideosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),rvideozoom_32x32);
	decreaseicon=new FXGIFIcon(getApp(),decrease_16x32); 
	increaseicon=new FXGIFIcon(getApp(),increase_16x32); 
	icnlisticon=new FXGIFIcon(getApp(),icnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),detlist_16x32);
  	return TRUE;
  }else if(theme=="classic"||theme=="moon"){
	audioicon=new FXGIFIcon(getApp(),b_audio);
	createicon=new FXGIFIcon(getApp(),b_previd);
	decreaseicon=new FXGIFIcon(getApp(),b_decvid);
	deleteicon=new FXGIFIcon(getApp(),b_trash);
	deletehiddenicon=new FXGIFIcon(getApp(),b_delvid);
	downicon=new FXGIFIcon(getApp(),b_down);
	dropicon=new FXGIFIcon(getApp(),b_conf);
	hiddenicon=new FXGIFIcon(getApp(),b_hidden);
	hideicon=new FXGIFIcon(getApp(),b_hide);
	increaseicon=new FXGIFIcon(getApp(),b_incvid);
	loopicon=new FXGIFIcon(getApp(),b_conf);
	openicon=new FXGIFIcon(getApp(),b_file);
	pauseicon=new FXGIFIcon(getApp(),b_pause);
	playicon=new FXGIFIcon(getApp(),b_play);
	quiticon=new FXGIFIcon(getApp(),b_quit);
	recreateicon=new FXGIFIcon(getApp(),b_frevid);
	showicon=new FXGIFIcon(getApp(),b_all);
	stopicon=new FXGIFIcon(getApp(),b_stop);
	upicon=new FXGIFIcon(getApp(),b_up);
	videoicon=new FXGIFIcon(getApp(),b_video);
	videoouticon=new FXGIFIcon(getApp(),b_videoout);
	videosizeicon=new FXGIFIcon(getApp(),b_videosize);
	videozoomicon=new FXGIFIcon(getApp(),b_videozoom);
	decreaseicon=new FXGIFIcon(getApp(),b_decvid); 
	increaseicon=new FXGIFIcon(getApp(),b_incvid); 
	icnlisticon=new FXGIFIcon(getApp(),b_icnlist);
	detlisticon=new FXGIFIcon(getApp(),b_detlist);
  	return TRUE;
  }else{
	theme="dark";
	audioicon=new FXGIFIcon(getApp(),audio_32x32);
	createicon=new FXGIFIcon(getApp(),create_32x32); 
	deleteicon=new FXGIFIcon(getApp(),delete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),deletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),down_32x32);
	dropicon=new FXGIFIcon(getApp(),drop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),hidden_32x32);
	hideicon=new FXGIFIcon(getApp(),hide_32x32); 
	loopicon=new FXGIFIcon(getApp(),loop_32x32);
	openicon=new FXGIFIcon(getApp(),open_32x32); 
	pauseicon=new FXGIFIcon(getApp(),pause_32x32);
	playicon=new FXGIFIcon(getApp(),play_32x32);
	quiticon=new FXGIFIcon(getApp(),quit_32x32);
	recreateicon=new FXGIFIcon(getApp(),recreate_32x32); 
	showicon=new FXGIFIcon(getApp(),show_32x32); 
	stopicon=new FXGIFIcon(getApp(),stop_32x32);
	upicon=new FXGIFIcon(getApp(),up_32x32);
	videoicon=new FXGIFIcon(getApp(),video_32x32);
	videoouticon=new FXGIFIcon(getApp(),videoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),videosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),videozoom_32x32);
	decreaseicon=new FXGIFIcon(getApp(),decrease_16x32); 
	increaseicon=new FXGIFIcon(getApp(),increase_16x32); 
	icnlisticon=new FXGIFIcon(getApp(),icnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),detlist_16x32);
  	return TRUE;
  } 
  return FALSE;
}


// load localization 
FXbool FXMovieManager::languageSelection() {
  language=getApp()->reg().readStringEntry("SETTINGS","language");

  if(language=="en"){
	quitbuttontext = "\tQuit\tQuit the application";
	openbuttontext = "\tAdd movies\tAdd movies to the playlist";
	audiobuttontext1 = "\tMute\tMPlayer must be running";
	audiobuttontext2 = "\tAudio\tMPlayer must be running";
	dropbuttontext1 = "\tDrop frames\tMPlayer must be running";
	dropbuttontext2 = "\tAll frames\tMPlayer must be running";
	stopbuttontext = "\tStop\tStop Player";
	pausebuttontext = "\tPause\tMPlayer must be running";
	playbuttontext = "\tPlay\tPlay the selected movies";
	loopbuttontext1 = "\tLoop\tPlay in loop";
	loopbuttontext2 = "\tOnce\tPlay once";
	zoombuttontext1 = "\tZoom\tZoom video size";
	zoombuttontext2 = "\t1:1\tReal video size";
	hidebuttontext1 = "\tHide\tHide playlist";
	hidebuttontext2 = "\tShow\tShow playlist";
	sizebuttontext = "\tSize\tVideo size";
	outputbuttontext = "\tOutput\tVideo output";
	confbuttontext = "\tConfiguration\tFxMovieManager Configuration";
	upbuttontext = "\tMove one step up\tMove one step up";
	downbuttontext = "\tMove one step down\tMove one step down";
  	allbuttontext1 = "\tSelect all movies\tSelect all movies";
	allbuttontext2 = "\tDeselect all movies\tDeselect all movies";
	createbuttontext = "\tCreate thumbnails\tCreate thumbnails";
	recreatebuttontext = "\tRecreate thumbnails\tRecreate thumbnails";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext = "\tDelete thumbnails\tDelete thumbnails";
	clearbuttontext = "\tClear the playlist\tClear the playlist";
	increasebuttontext = "\tIncrease thumbnails size\tIncrease thumbnails size";
	decreasebuttontext = "\tDecrease thumbnails size\tDecrease thumbnails size";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  }else if(language=="it"){
	quitbuttontext = "\tEsci\tEsci dal programma";
	openbuttontext = "\tAggiungi\tAggiungi films alla lista";
	audiobuttontext1 = "\tMuto\tMPlayer deve essere in esecuzione";
	audiobuttontext2 = "\tAudio\tMPlayer deve essere in esecuzione";
	dropbuttontext1 = "\tSfoltisci i frames\tMPlayer deve essere in esecuzione";
	dropbuttontext2 = "\tTutti i frames\tMPlayer deve essere in esecuzione";
	stopbuttontext = "\tInterrompi\tInterrompi";
	pausebuttontext = "\tPausa\tMPlayer deve essere in esecuzione";
	playbuttontext = "\tGuarda\tGuarda i films selezionati";
	loopbuttontext1 = "\tContinuamente\tGuarda continuamente";
	loopbuttontext2 = "\tUna Volta\tGuarda un volta";
	zoombuttontext1 = "\tZoom\tZoom del video";
	zoombuttontext2 = "\t1:1\tDimensioni del video reali";
	hidebuttontext1 = "\tNascondi\tNascondi la lista";
	hidebuttontext2 = "\tMostra\tMostra la lista";
	sizebuttontext = "\tDimensioni\tDimensioni video";
	outputbuttontext = "\tUscita\tUscita video";
	confbuttontext = "\tConfigurazione\tConfigurazione di FxMovieManager";
	upbuttontext = "\tSposta in alto\tSposta in alto di un gradino";
	downbuttontext = "\tSposta in basso\tSposta in basso di un gradino";
  	allbuttontext1 = "\tSeleziona tutti\tSeleziona tutti i filmati";
	allbuttontext2 = "\tDeseleziona tutti\tDeseleziona tutti i filmati";
	createbuttontext = "\tCrea l'anteprima\tCrea l'anteprima";
	recreatebuttontext = "\tRicrea l'anteprima\tRicrea l'anteprima";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext = "\tElimina l'anteprima\tElimina l'anteprima";
	clearbuttontext = "\tCancella la lista\tCancella la lista";
	increasebuttontext = "\tIngrandisci l'anteprima\tIngrandisci l'anteprima";
	decreasebuttontext = "\tRiduci l'anteprima\tRiduci l'anteprima";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  }else if(language=="fr"){
	quitbuttontext = "\tQuittez l'application\tQuittez l'application";
	openbuttontext = "\tAjouter à la liste de films\tAjouter à la liste de films";
	audiobuttontext1 = "\tMute\tMPlayer doit être en cours d'exécution";
	audiobuttontext2 = "\tAudio\tMPlayer doit être en cours d'exécution";
	dropbuttontext1 = "\tRéduire les images\tMPlayer doit être en cours d'exécution";
	dropbuttontext2 = "\tToutes les images\tMPlayer doit être en cours d'exécution";
	stopbuttontext = "\tArrêter\tMPlayer doit être en cours d'exécution";
	pausebuttontext = "\tPause\tMPlayer doit être en cours d'exécution";
	playbuttontext = "\tRegarder\tRegarder les films sélectionnés";
	loopbuttontext1 = "\tBoucle\tRegarder en boucle";
	loopbuttontext2 = "\tOne fois\tRegarder une fois";
	zoombuttontext1 = "\tZoom\tZoom taille vidéo";
	zoombuttontext2 = "\t1:1\t1:1 taille vidéo";
	hidebuttontext1 = "\tMasquer\tMasquer la liste de film";
	hidebuttontext2 = "\tVoir\tVoir la liste de film";
	sizebuttontext = "\tTaille\ttaille de la vidéo";
	outputbuttontext = "\tSortie\tSortie vidéo";
	confbuttontext = "\tConfiguration\tConfigurer FxMovieManager";
	upbuttontext = "\tDéplacer vers le haut\tDéplacer vers le haut";
	downbuttontext = "\tDéplacez vers le bas\tDéplacez vers le bas";
  	allbuttontext1 = "\tSélectionnez tous les films\tSélectionnez tous les films";
	allbuttontext2 = "\tDésactivez tous les films\tDésactivez tous les films";
	createbuttontext = "\tCrée une prévisualisation\tCrée une prévisualisation";
	recreatebuttontext = "\tRecrée une prévisualisation\tRecrée une prévisualisation";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext = "\tSupprimer une prévisualisation\tSupprimer une prévisualisation";
	clearbuttontext = "\tEffacer la liste de film\tEffacer la liste de film";
	increasebuttontext = "\tAugmenter la taille de prévisualisation\tAugmenter la taille de prévisualisation";
	decreasebuttontext = "\tDiminution de prévisualisation\tDiminution de prévisualisation";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  }else if(language=="de"){
	quitbuttontext = "\tSchließen Sie das Programm\tSchließen Sie das Programm";
	openbuttontext = "\tHinzufügen zur Liste Filme\tHinzufügen zur Liste Filme";
	audiobuttontext1 = "\tMute\tMplayer muss ausgeführt werden";
	audiobuttontext2 = "\tAudio\tMplayer muss ausgeführt werden";
	dropbuttontext1 = "\tVerringerung der Bilder\tMplayer muss ausgeführt werden";
	dropbuttontext2 = "\tAlle bilder\tMplayer muss ausgeführt werden";
	stopbuttontext = "\tStoppen\tMplayer muss ausgeführt werden";
	pausebuttontext = "\tPause\tMplayer muss ausgeführt werden";
	playbuttontext = "\tSehen Sie den Film\tSehen Sie sich die ausgewählten Filme";
	loopbuttontext1 = "\tKontinuierlich\tSehen Sie den Film kontinuierlich";
	loopbuttontext2 = "\tEinmal\tSchauen Sie einmal";
	zoombuttontext1 = "\tZoom\tZoom Video-Größe";
	zoombuttontext2 = "\t1:1\tReal Video-Größe";
	hidebuttontext1 = "\tAusblenden\tAusblenden der Liste der Filme";
	hidebuttontext2 = "\tZeigt\tZeigt die Liste der Filme";
	sizebuttontext = "\tGröße\tVideo-Größe";
	outputbuttontext = "\tAusgang\tVideo-Ausgang";
	confbuttontext= "\tKonfiguration\tKonfigurieren FxMovieManager";
	upbuttontext= "\tEinen Schritt bis\tBewegen Sie ein Schritt bis";
	downbuttontext= "\tEinen Schritt nach unten\tBewegen Sie ein Schritt nach unten";
  	allbuttontext1= "\tWählen Sie alle Filme\tWählen Sie alle Filme";
	allbuttontext2= "\tDeaktivieren Sie alle Filme\tDeaktivieren Sie alle Filme";
	createbuttontext= "\tSchafft Vorschau\tSchafft Vorschau";
	recreatebuttontext= "\tStellt Vorschau\tStellt Vorschau";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext= "\tEliminiert Vorschau\tEliminiert Vorschau";
	clearbuttontext= "\tLöscht die Liste der Filme\tLöscht die Liste der Filme";
	increasebuttontext= "\tVergrössern Vorschau\tVergrössern Vorschau";
	decreasebuttontext= "\tNiederösterreich Vorschau\tNiederösterreich Vorschau";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  }else if(language=="es"){
	quitbuttontext = "\tSalir del programa\tSalir del programa";
	openbuttontext = "\tAñadir a la lista de películas\tAñadir a la lista de películas";
	audiobuttontext1 = "\tMudo\tMPlayer debería estar ejecutándose";
	audiobuttontext2 = "\tAudio\tMPlayer debería estar ejecutándose";
	dropbuttontext1 = "\tReducir las imágenes\tMPlayer debería estar ejecutándose";
	dropbuttontext2 = "\tTodas las imágenes\tMPlayer debería estar ejecutándose";
	stopbuttontext = "\tParar\tMPlayer debería estar ejecutándose";
	pausebuttontext = "\tRomper\tMPlayer debería estar ejecutándose";
	playbuttontext = "\tMira\tMira las películas seleccionadas";
	loopbuttontext1 = "\tContinua\tMira continua";
	loopbuttontext2 = "\tUna vez\tMira una vez";
	zoombuttontext1 = "\tZoom\tVideo Zoom";
	zoombuttontext2 = "\t1:1\tTamaño real del video";
	hidebuttontext1 = "\tOcultar\tOcultar la lista de películas";
	hidebuttontext2 = "\tMuestra\tMuestra la lista de películas";
	sizebuttontext = "\tTamaño\tel tamaño video";
	outputbuttontext = "\tSalida\tsalida de vídeo";
	confbuttontext = "\tConfiguración\tConfiguración de FXMovieManager";
	upbuttontext = "\tSales de un paso\tSales de un paso";
	downbuttontext = "\tBajar un paso\tBajar un paso";
	allbuttontext1 = "\tSeleccione todas las películas\tSeleccione todas las películas";
	allbuttontext2 = "\tDesmarque todas las películas\tDesmarque todas las películas";
	createbuttontext = "\tCrear una vista previa\tCrear una vista previa";
	recreatebuttontext = "\tRecrear la vista previa\tRecrear la vista previa";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext = "\tEliminar la vista previa\tEliminar la vista previa";
	clearbuttontext = "\tBorrar la lista de películas\tBorrar la lista de películas";
	increasebuttontext = "\tAmpliar la vista previa\tAmpliar la vista previa";
	decreasebuttontext = "\tMenos de vista previa\tMenos de vista previa";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  }else if(language=="ru"){
	quitbuttontext = "\tВыход\tВыход из программы";
	openbuttontext = "\tДобавить\tДобавить в список фильмов";
	audiobuttontext1 = "\tТупой\tMPlayer должна быть запущена";
	audiobuttontext2 = "\tАудио\tMPlayer должна быть запущена";
	dropbuttontext1 = "\tСнижение изображений\tMPlayer должна быть запущена";
	dropbuttontext2 = "\tВсе изображения\tMPlayer должна быть запущена";
	stopbuttontext = "\tОстановка\tОстановка";
	pausebuttontext = "\tПерерыв\tMPlayer должна быть запущена";
	playbuttontext = "\tПосмотреть\tСмотреть фильмы выбранные";
	loopbuttontext1 = "\tНепрерывно\tПосмотреть постоянно";
	loopbuttontext2 = "\tОднажды\tОдин раз увидеть";
	zoombuttontext1 = "\tУвеличить\tУвеличить видео";
	zoombuttontext2 = "\t1:1\tРазмер реального видео";
	hidebuttontext1 = "\tПрятать\tСкрыть список";
	hidebuttontext2 = "\tПоказывать\tПосмотреть список";
	sizebuttontext = "\tРазмер\tРазмер видео";
	outputbuttontext = "\tвидеовыходу\tвидеовыходу";
	confbuttontext = "\tКонфигурация\tНастройка FxMovieManager";
	upbuttontext = "\tВверх\tВверх шаг";
	downbuttontext = "\tВнизo\tВниз шаг";
  	allbuttontext1 = "\tВыбрать все\tВыбрать все фильмы";
	allbuttontext2 = "\tСнять все\tСнимите все фильмы";
	createbuttontext = "\tСоздать прослушать\tСоздать прослушать";
	recreatebuttontext = "\tЗаново прослушать\tЗаново прослушать";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext = "\tУдалить прослушать\tУдалить прослушать";
	clearbuttontext = "\tУдалить список\tУдалить список";
	increasebuttontext = "\tУвеличить прослушать\tУвеличить прослушать";
	decreasebuttontext = "\tМинус прослушать\tМинус прослушать";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  }else{
	language="en";
	quitbuttontext = "\tQuit\tQuit the application";
	openbuttontext = "\tAdd movies\tAdd movies to the playlist";
	audiobuttontext1 = "\tMute\tMPlayer must be running";
	audiobuttontext2 = "\tAudio\tMPlayer must be running";
	dropbuttontext1 = "\tDrop frames\tMPlayer must be running";
	dropbuttontext2 = "\tAll frames\tMPlayer must be running";
	stopbuttontext = "\tStop\tStop Player";
	pausebuttontext = "\tPause\tMPlayer must be running";
	playbuttontext = "\tPlay\tPlay the selected movies";
	loopbuttontext1 = "\tLoop\tPlay in loop";
	loopbuttontext2 = "\tOnce\tPlay once";
	zoombuttontext1 = "\tZoom\tZoom video size";
	zoombuttontext2 = "\t1:1\tReal video size";
	hidebuttontext1 = "\tHide\tHide playlist";
	hidebuttontext2 = "\tShow\tShow playlist";
	sizebuttontext = "\tSize\tVideo size";
	outputbuttontext = "\tOutput\tVideo output";
	confbuttontext = "\tConfiguration\tFxMovieManager Configuration";
	upbuttontext = "\tMove one step up\tMove one step up";
	downbuttontext = "\tMove one step down\tMove one step down";
  	allbuttontext1 = "\tSelect all movies\tSelect all movies";
	allbuttontext2 = "\tDeselect all movies\tDeselect all movies";
	createbuttontext = "\tCreate thumbnails\tCreate thumbnails";
	recreatebuttontext = "\tRecreate thumbnails\tRecreate thumbnails";
  	widebuttontext1 = "\tWideScreen\tShow WideScreen Thumbnails";
	widebuttontext2 = "\tNormalScreen\tShow NormalScreen Thumbnails";
	deletebuttontext = "\tDelete thumbnails\tDelete thumbnails";
	clearbuttontext = "\tClear the playlist\tClear the playlist";
	increasebuttontext = "\tIncrease thumbnails size\tIncrease thumbnails size";
	decreasebuttontext = "\tDecrease thumbnails size\tDecrease thumbnails size";
	detlisttext = "\tdetailed list view\tdetailed list view";
	icnlisttext = "\tIcon list view\tIcon list view";
  	return TRUE;
  } 
  return FALSE;
}


// load configuration
FXbool FXMovieManager::readConfig() {

  // Get size and position
#ifdef FOX_17
  FXuint width=getApp()->reg().readUIntEntry("WINDOW","width",800);
  FXuint height=getApp()->reg().readUIntEntry("WINDOW","height",54);
#endif
#ifdef FOX_16
  FXuint width=getApp()->reg().readUnsignedEntry("WINDOW","width",800);
  FXuint height=getApp()->reg().readUnsignedEntry("WINDOW","height",54);
#endif 

  FXint xpos=getApp()->reg().readIntEntry("WINDOW","xpos",40);
  FXint ypos=getApp()->reg().readIntEntry("WINDOW","ypos",5);

  // Reposition window
  position(xpos,ypos,width,height);

  // Read menu options
  s_full=getApp()->reg().readStringEntry("MENU","s_full");
  s_loop=getApp()->reg().readStringEntry("MENU","s_loop");
  s_frame=getApp()->reg().readStringEntry("MENU","s_frame");
  s_audio=getApp()->reg().readStringEntry("MENU","s_audio");

  i_video=getApp()->reg().readIntEntry("MENU","s_video",i_video);
  i_size=getApp()->reg().readIntEntry("MENU","s_size",i_size);

  s_listshow=getApp()->reg().readStringEntry("MENU","s_listshow");

  currentdir=getApp()->reg().readStringEntry("FileList","currentdir");

  splitter2->setSplit(0,getApp()->reg().readIntEntry("FileList","dirwidth",260));
  splitter1->setSplit(1,getApp()->reg().readIntEntry("FileList","dirheigth",380));

  // Read registry settings
  getApp()->reg().read();

  return TRUE;
}

// create application
void FXMovieManager::create() {

  readConfig();

  dirlist->setDirectory(currentdir);
  filelist->setDirectory(currentdir);

  if(s_listshow=="false"){ hidebutton->setState(TRUE); listshow=false; } 
  else if(s_listshow=="true"){ hidebutton->setState(FALSE); listshow=true;}

  if(s_full==""){ zoombutton->setState(FALSE); } 
  else if(s_full=="-fs "){ zoombutton->setState(TRUE); }

  if(s_loop==""){ loopbutton->setState(FALSE); } 
  else if(s_loop=="-loop 0 "){ loopbutton->setState(TRUE); }

  if(s_audio==""){ audiobutton->setState(FALSE); } 
  else if(s_audio=="-nosound "){ audiobutton->setState(TRUE); }

  if(s_frame==""){ dropbutton->setState(FALSE); } 
  else if(s_frame=="-framedrop "){ dropbutton->setState(TRUE); }

  switch(i_video){
	case 1:
		s_video="-vo x11 -fixed-vo ";
		break;
	case 2:
		s_video="-vo xv -fixed-vo ";
		break;
	case 3:
		s_video="-vo gl2 -fixed-vo ";
		break;
	case 4:
		s_video="-vo sdl -fixed-vo ";
		break;
	case 5:
		s_video="-vo dga -fixed-vo ";
		break;
	case 6:
		s_video="-vo xvidix -fixed-vo ";
		break;
	case 7:
		s_video="-vo jpeg ";
		break;
	case 8:
		s_video="-vo png ";
		break;
	case 9:
		s_video="-vo null ";
		break;
	}

  switch(i_size){
	case 1:
		s_size="-zoom -x 720 -y 576 ";
		break;
	case 2:
		s_size="-zoom -x 640 -y 480 ";
		break;
	case 3:
		s_size="-zoom -x 500 -y 284 ";
		break;
	case 4:
		s_size="-zoom -x 480 -y 576 ";
		break;
	case 5:
		s_size="-zoom -x 480 -y 480 ";
		break;
	case 6:
		s_size="-zoom -x 352 -y 288 ";
		break;
	case 7:
		s_size="-zoom -x 352 -y 240 ";
		break;
	case 8:
		s_size="-zoom -x 320 -y 240 ";
		break;
	case 9:
		s_size="";
		break;
	}
  getApp()->addTimeout(this,ID_CLOCKTIME,CLOCKTIMER);
  FXMainWindow::create();
  show(PLACEMENT_SCREEN);
}


// quit application
long FXMovieManager::onCmdQuit(FXObject *,FXSelector,void *) {

  quitAppFxmm();
  return 1;
}


void FXMovieManager::quitAppFxmm(){
 
  FXTRACE((100,"Quit\n"));
  // Write new window size and position back to registry
#ifdef FOX_17
  getApp()->reg().writeUIntEntry("WINDOW","width",(FXuint)getWidth());
  getApp()->reg().writeUIntEntry("WINDOW","height",(FXuint)getHeight());
#endif
#ifdef FOX_16
  getApp()->reg().writeUnsignedEntry("WINDOW","width",(FXuint)getWidth());
  getApp()->reg().writeUnsignedEntry("WINDOW","height",(FXuint)getHeight());
#endif 
  getApp()->reg().writeIntEntry("WINDOW","xpos",getX());
  getApp()->reg().writeIntEntry("WINDOW","ypos",getY());

  // Write mencoder options
  getApp()->reg().writeIntEntry("MENU","s_video",i_video);
  getApp()->reg().writeIntEntry("MENU","s_size",i_size);

  getApp()->reg().writeStringEntry("MENU","s_full",s_full.text());
  getApp()->reg().writeStringEntry("MENU","s_loop",s_loop.text());
  getApp()->reg().writeStringEntry("MENU","s_frame",s_frame.text());
  getApp()->reg().writeStringEntry("MENU","s_audio",s_audio.text());

  if (listshow==true) {s_listshow="true";}
  else if (listshow==false) {s_listshow="false";}
  getApp()->reg().writeStringEntry("MENU","s_listshow",s_listshow.text());

  currentdir = dirlist->getDirectory();
  getApp()->reg().writeStringEntry("FileList","currentdir",currentdir.text());

  getApp()->reg().writeIntEntry("FileList","dirwidth",splitter2->getSplit(0));
  getApp()->reg().writeIntEntry("FileList","dirheigth",splitter1->getSplit(1));

  // Write registry settings
  getApp()->reg().write();

  system ("test -p /tmp/.fxmm/fifo && rm /tmp/.fxmm/fifo");

  // Quit
  getApp()->exit(0);
}


/**************************PLAYER BUTTON COMMANDS****************************/


// select multiple files
long FXMovieManager::onCmdFile(FXObject *,FXSelector,void *) {

	// Remove all items from list
	simplelist->clearItems();
	getFiledialogSelection();
	return 1;
}


// Change video output
long FXMovieManager::onCmdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_video=FXSELID(sel)-ID_VIDEO_1+1;
  if(0<=n_video && n_video<10){
    switch(FXSELID(sel)){
	case ID_VIDEO_1:
		i_video=1;
		s_video="-vo x11 -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output x11 Enabled\nVideo on Top Enabled");
		break;
	case ID_VIDEO_2:
		i_video=2;
		s_video="-vo xv -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output xv Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_3:
		i_video=3;
		s_video="-vo gl2 -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output gl2 Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_4:
		i_video=4;
		s_video="-vo sdl -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output sdl Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_5:
		i_video=5;
		s_video="-vo dga -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output dga Enabled");
		break;
	case ID_VIDEO_6:
		i_video=6;
		s_video="-vo xvidix -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output xvidix Enabled");
		break;
	case ID_VIDEO_7:
		i_video=7;
		s_video="-vo jpeg ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Output >>> jpeg files enabled");
		break;
	case ID_VIDEO_8:
		i_video=8;
		s_video="-vo png ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Output >>> png files enabled");
		break;
	case ID_VIDEO_9:
		i_video=9;
		s_video="-vo null ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output Disabled");
		break;
      }
    }
  return 1;
  }


// Update video output
long FXMovieManager::onUpdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_video=FXSELID(sel)-ID_VIDEO_1+1;
  sender->handle(this,i_video==n_video?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }


// Change video size
long FXMovieManager::onCmdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_size=FXSELID(sel)-ID_SIZE_1+1;
  if(0<=n_size && n_size<10){
    switch(FXSELID(sel)){
	case ID_SIZE_1:
		i_size=1;
		s_size="-zoom -x 720 -y 560 ";
		break;
	case ID_SIZE_2:
		i_size=2;
		s_size="-zoom -x 640 -y 480 ";
		break;
	case ID_SIZE_3:
		i_size=3;
		s_size="-zoom -x 500 -y 284 ";
		break;
	case ID_SIZE_4:
		i_size=4;
		s_size="-zoom -x 480 -y 576 ";
		break;
	case ID_SIZE_5:
		i_size=5;
		s_size="-zoom -x 480 -y 480 ";
		break;
	case ID_SIZE_6:
		i_size=6;
		s_size="-zoom -x 352 -y 288 ";
		break;
	case ID_SIZE_7:
		i_size=7;
		s_size="-zoom -x 352 -y 240 ";
		break;
	case ID_SIZE_8:
		i_size=8;
		s_size="-zoom -x 320 -y 240 ";
		break;
	case ID_SIZE_9:
		i_size=9;
		s_size="";
		break;
      }
    }
  return 1;
  }


// Update video size
long FXMovieManager::onUpdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_size=FXSELID(sel)-ID_SIZE_1+1;
  sender->handle(this,i_size==n_size?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }


// list play command
long FXMovieManager::onCmdPlay(FXObject *,FXSelector,void *) {

	// reset the fifo every time we play
	system ("test -p /tmp/.fxmm/fifo && rm /tmp/.fxmm/fifo");
	system ("test -p /tmp/.fxmm/fifo || mkfifo /tmp/.fxmm/fifo");

	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
//	printf("The number of items was %d\n", numberofitems);
	if(numberofitems >= 0){
		// Return the text of all items
		for(int i=0; i<numberofitems; ++i){
		if(simplelist->isItemSelected(i)){
			s_list += simplelist->getItemText(i);
			s_list += " ";
			// simplelist->deselectItem(i);
			// simplelist->repaint();
			}
		}
	}

	//get the position where to start playing of the movie	
	s_initial = "-ss " + seekposition1->getText() + ":" + seekposition2->getText() + ":" + seekposition3->getText() + " ";
	s_duration = "-endpos " + endposition1->getText() + ":" + endposition2->getText() + ":" + endposition3->getText() + " ";

	//get the speed
	FXfloat i_speed = speedslider->getValue();
	FXfloat f_speed = (i_speed/10);
	FXString s_speed = "-speed " + (FXString::value(f_speed,2)) + " ";

	//get the volume
	FXint i_volume = volumeslider->getValue();
	FXString s_volume = "-volume " + (FXString::value(i_volume)) + " 5 ";

	// correct command list sequence....
	FXString i_command = s_command + s_video + s_size + s_full + s_speed + s_audio + s_volume + s_frame + s_loop + s_initial + s_duration;

	s_play = i_command + s_list +"&";
	printf("The playstring was: %s\n", s_play.text());

/*
	if(isrunning==FALSE){
		system(s_play.text());
		isrunning = TRUE;
	} else if(isrunning==TRUE){ 
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "pause\n");
		fclose(f);
	}
*/
	system("killall mplayer");
	system(s_play.text());

    int fd;
    // Spawn child
    if(fork()==0){
      // Close on exec of file descriptor
      fcntl(fd,F_SETFD,TRUE);
      // Start command and pass it the playlist
      execlp(i_command.text(),i_command.text(),s_list.text(),NULL);
      // In case we failed to execute the command
      ::exit(0);
      }

	isrunning = TRUE;
	// clear liststr
	s_list = "";
	s_play = "";
	return 1;
}


// playlist pause command
long FXMovieManager::onCmdPause(FXObject *,FXSelector,void *) {
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "pause\n");
		fclose(f);
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}


// playlist stop command
long FXMovieManager::onCmdStop(FXObject *,FXSelector,void *) {
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "quit 1\n");
		fclose(f);
		isrunning=FALSE;
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}

// playlist audio command
long FXMovieManager::onCmdAudio(FXObject *,FXSelector,void *) {
    if(isrunning==TRUE){
		if(s_audio==""){
			FILE *f;
			f=fopen("/tmp/.fxmm/fifo", "w");
			fprintf(f, "%s", "mute 1\n");
			fclose(f);
			s_audio="-nosound ";
		} else if(s_audio=="-nosound "){
			FILE *f;
			f=fopen("/tmp/.fxmm/fifo", "w");
			fprintf(f, "%s", "mute 0\n");
			fclose(f);
			s_audio= "";
		}
    } else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
		if(s_audio==""){
			s_audio="-nosound ";
		} else if(s_audio=="-nosound "){
			s_audio= "";
		}
    }
    return 1;
}

// playlist frame drop command
long FXMovieManager::onCmdDrop(FXObject *,FXSelector,void *) {
    if(isrunning==TRUE){
		if(s_frame==""){
			FILE *f;
			f=fopen("/tmp/.fxmm/fifo", "w");
			fprintf(f, "%s", "frame_drop 1\n");
			fclose(f);
			s_frame = "-framedrop ";
		} else if(s_frame=="-framedrop "){
			FILE *f;
			f=fopen("/tmp/.fxmm/fifo", "w");
			fprintf(f, "%s", "frame_drop 0\n");
			fclose(f);
			s_frame = "";
		}
    } else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	if(s_frame==""){
		s_frame = "-framedrop ";
	} else if(s_frame=="-framedrop "){
		s_frame = "";
	}
    }
    return 1;
}

// playlist video zoom command
long FXMovieManager::onCmdFull(FXObject *,FXSelector,void *) {
	if(s_full==""){
		s_full = "-fs ";
		zoombutton->setState(TRUE);
	} else if(s_full=="-fs "){
		s_full = "";
		zoombutton->setState(FALSE);
	}
	return 1;
}

// playlist loop command
long FXMovieManager::onCmdLoop(FXObject *,FXSelector,void *) {
	if(s_loop==""){
		s_loop = "-loop 0 ";
		loopbutton->setState(TRUE);
	} else if(s_loop=="-loop 0 "){
		s_loop = "";
		loopbutton->setState(FALSE);
	}
	return 1;
}

// playlist-filemanager hide command
long FXMovieManager::onCmdPutBack(FXObject *,FXSelector,void *) {
	if (listshow==false) {
		FXMainWindow::setHeight(600);
		FXMainWindow::repaint();
       	FXMainWindow::show(PLACEMENT_SCREEN);
		listshow=true;
		hidebutton->setState(FALSE);
	} else if (listshow==true) {
		FXMainWindow::setHeight(54);
		FXMainWindow::repaint();
        FXMainWindow::show(PLACEMENT_SCREEN);
		listshow=false;
		hidebutton->setState(TRUE);
	}
	return 1;
}

/**************************PLAYER LIST COMMANDS****************************/

// Move Up Command
long FXMovieManager::onCmdMoveUp(FXObject*,FXSelector,void*){
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber >= 0){
		FXint newindexnumber = indexnumber-1;
		if(newindexnumber>=0){
			// Move Down the current item
			simplelist->moveItem(newindexnumber,indexnumber);
		}
	}
	return 1;
}

// Move Down Command
long FXMovieManager::onCmdMoveDown(FXObject*,FXSelector,void*){
	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber >= 0){
		FXint newindexnumber = indexnumber+1;
		if(newindexnumber<numberofitems){
			// Move Down the current item
			simplelist->moveItem(newindexnumber,indexnumber);
		}
	}
	return 1;
}


// Append command
long FXMovieManager::onCmdAppend(FXObject *,FXSelector,void *) {
	getFiledialogSelection();
	return 1;
}


// Insert Command ------------------TO DO
long FXMovieManager::onCmdInsert(FXObject*,FXSelector,void*){
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber < 0){
		FXMessageBox::error(this,MBOX_OK,"The list may be empty","Error Inserting File");
		return 1;
	}

	FXFileDialog open(this,"Insert Movie");
	open.setFilename(filename);
	if(open.execute()){
		filename=open.getFilename();
		// Insert at the current item position
		simplelist->insertItem(indexnumber, filename);
	}
	return 1;
}


// Replace Command-----------------TO DO
long FXMovieManager::onCmdReplace(FXObject*,FXSelector,void*){
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber < 0){
		FXMessageBox::error(this,MBOX_OK,"The list may be empty","Error Replacing File");
		return 1;
	}

	FXFileDialog open(this,"Replace Movie");
	open.setFilename(filename);
	if(open.execute()){
		filename=open.getFilename();
		// Replace the current item
		simplelist->setItemText(indexnumber, filename);
	}
	return 1;
}


// Select All Command
long FXMovieManager::onCmdSelectAll(FXObject*,FXSelector,void*){
	selectAll();
	return 1;
}


// Delete Command
long FXMovieManager::onCmdDelete(FXObject*,FXSelector,void*){
	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
	if(numberofitems >= 0){
		// Remove all selected items
		for(int i=(numberofitems-1); i>=0; --i){
		if(simplelist->isItemSelected(i)){
			//printf("The item index selected was %d\n", i);
			simplelist->removeItem(i);
			}
		}
	}
/*
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber >=0){
	// Remove the current item
	simplelist->removeItem(indexnumber);
	}
*/
	return 1;
}


// Clear Command
long FXMovieManager::onCmdClear(FXObject*,FXSelector,void*){
	// Remove all items from list
	simplelist->clearItems();
	return 1;
}


// Released right button
long FXMovieManager::onListRightMouse(FXObject*,FXSelector,void* ptr){
  FXEvent* event=(FXEvent*)ptr;
  if(!event->moved){
    popupmenu->popup(NULL,event->root_x,event->root_y);
    getApp()->runModalWhileShown(popupmenu);
    }
  return 1;
}


// Enable sender when items have been selected
long FXMovieManager::onUpdSelectedList(FXObject* sender,FXSelector,void*){
  sender->handle(this,getNumListnames()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }


// Select All Command
void FXMovieManager::selectAll(){
	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
	if(numberofitems >= 0){
		for (int i=0; i<numberofitems; ++i){
			simplelist->selectItem(i);
		}
	}
  }


// Get number of selected filenames, not including "." and ".."
FXint FXMovieManager::getNumListnames() const {
  register FXint listnum=0;
  register FXint e;
  if(simplelist->getNumItems()){
    for(e=0; e<simplelist->getNumItems(); e++){
      if(simplelist->isItemSelected(e)) listnum++;
      }
    }
  return listnum;
  }

/****************************DIRECTORY LIST**********************************/

// Create new directory
long FXMovieManager::onCmdNewDir(FXObject*,FXSelector,void*){
  FXDialogBox dialog(this,"Create New Directory",DECOR_TITLE|DECOR_BORDER);
  const FXchar suggestedname[]="DirectoryName";
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Create new directory in: "+filelist->getDirectory(),NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(suggestedname);
  text->setFocus();
  text->setSelection(0,sizeof(suggestedname));

  if(dialog.execute()){
    FXString dirname=FXPath::absolute(filelist->getDirectory(),text->getText());
    if(FXStat::exists(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Already Exists","File or directory %s already exists.\n",dirname.text());
      }
    else if(!FXDir::create(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Cannot Create","Cannot create directory %s.\n",dirname.text());
      }
    else {
      currentdir=dirname;
      dirlist->setDirectory(currentdir);
      filelist->setDirectory(currentdir);
    }
  }
  return 1;
}

// Delete directory the directory list
long FXMovieManager::onCmdDirDelete(FXObject*,FXSelector,void*){
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Directory","Are you sure you want to delete this directory?");
  if(answer==MBOX_CLICKED_YES){

    FXString dropdir=dirlist->getDirectory();
    FXTRACE((100,"dropdir=%s\n",dropdir.text()));
        if(!FXDir::remove(dropdir)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Directory","Unable to delete directory: %s\nContinue with operation?",dropdir.text())){
            return 1;
            }
        } else {
	  		currentdir=FXPath::absolute(dirlist->getDirectory());
  	  		dirlist->setDirectory(currentdir);
  	  		filelist->setDirectory(currentdir);
		}
    }
  return 1;
  }

// Rename directory in the directory list
long FXMovieManager::onCmdDirRename(FXObject*,FXSelector,void*){

  FXString dirname=dirlist->getDirectory();

  FXDialogBox dialog(this,"Rename Directory",DECOR_TITLE|DECOR_BORDER);
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Old Directory Name: "+dirname,NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(dirname);
  text->setFocus();

  if(dialog.execute()){

      //FXString suggestedname=FXPath::absolute(dirlist->getDirectory(),text->getText());
      FXString suggestedname=FXPath::absolute(text->getText());

      if(!FXDir::rename(dirname,suggestedname)){
        FXMessageBox::error(this,MBOX_OK,"Cannot Rename","Cannot Rename directory %s.\n",dirname.text());
      }
      else{
		//currentdir=FXPath::absolute(dirlist->getDirectory(),text->getText());
		currentdir=FXPath::absolute(text->getText());
  		dirlist->setDirectory(currentdir);
  		filelist->setDirectory(currentdir);
      }	
   } 
   return 1;
  }


// Update create new directory
long FXMovieManager::onUpdNewDir(FXObject* sender,FXSelector,void*){
  FXString path=filelist->getDirectory();
  if(FXStat::isWritable(path))
    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
  else
    sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }


// Change the directory from the FXDirList
long FXMovieManager::onCmdDirectory(FXObject*,FXSelector,void* ptr){
  FXTreeItem *item=(FXTreeItem*)ptr;
  FXString path=dirlist->getItemPathname(item);
  filelist->setDirectory(path);
  return 1;
  }


// Move up one directory
long FXMovieManager::onCmdUpDirectory(FXObject*,FXSelector,void*){
  FXString path=FXPath::upLevel(filelist->getDirectory());
  filelist->setDirectory(path);
  dirlist->setDirectory(path);
  return 1;
  }


// Popup menu for item in dir list
long FXMovieManager::onDirListPopup(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;

  FXMenuPane pane(dirlist);

    FXLabel *dirlistlabel = new FXLabel(&pane,"Directory Item");
    dirlistlabel->setTextColor(FXRGB(150,0,0));

    new FXMenuCommand(&pane,"New Dir...",m_appendicon,this,ID_NEWDIR);
    new FXMenuCommand(&pane,"Show/Hide",m_showhiddenicon,dirlist,FXDirList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(&pane,"Rename Dir",m_renamediricon,this,ID_DIRRENAME);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"Delete Dir",m_deleteicon,this,ID_DIRDELETE);

  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }


/****************************FILE LIST**********************************/

// Popup menu for item in file list
long FXMovieManager::onFileListPopup(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;
  FXint index=filelist->getItemAt(event->win_x,event->win_y);
  FXMenuPane pane(filelist);

  // We clicked in the background
  if(index<0){
    FXLabel *filebacklabel = new FXLabel(&pane,"Backgroung");
    filebacklabel->setTextColor(FXRGB(150,0,0));

    new FXMenuCommand(&pane,"Terminal",NULL,this,ID_TERMINAL);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"New Dir...",m_appendicon,this,ID_NEWDIR);
    new FXMenuCommand(&pane,"Show/Hide",m_showhiddenicon,filelist,FXFileList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(&pane,"Refresh",m_refreshicon,filelist,FXFileList::ID_REFRESH);
    }

  // We clicked on an item file or directory
  else{
    FXLabel *filelistlabel = new FXLabel(&pane,"File Item");
    filelistlabel->setTextColor(FXRGB(150,0,0));

    new FXMenuCommand(&pane,"Open...",m_appendicon,this,ID_OPEN);
    new FXMenuCommand(&pane,"Open With",m_appendicon,this,ID_OPENWITH);
    new FXMenuCommand(&pane,"Properties",m_propicon,this,ID_PROPERTIES);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"Rename...",m_renameicon,this,ID_FILERENAME);
    new FXMenuCommand(&pane,"Symlink...",m_moveicon,this,ID_FILESYMLINK);
    new FXMenuCommand(&pane,"Copy...",m_copyicon,this,ID_FILECOPY);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"DELETE...",m_deleteicon,this,ID_FILEDELETE);
    }
  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }

// Command from the tree list
long FXMovieManager::onCmdFileList(FXObject*,FXSelector,void* ptr){
  FXint index=(FXint)(FXival)ptr;
  if(0<=index){
    if(filelist->isItemDirectory(index)){
      filelist->setDirectory(filelist->getItemPathname(index));
      }
    else if(filelist->isItemFile(index)){
      filename=filelist->getItemPathname(index);
      loadfile(filename);
      getFilelistSelection();
      }
    }
  return 1;
}


// Symlink file or directory
long FXMovieManager::onCmdFileSymlink(FXObject*,FXSelector,void*){
	deselectMainDir();
	FXString rootname,imagename,newname;
  	FXString *filenamelist=getFilenames();

  	if(filenamelist){
    	OperationsDialog operationsdialog(this,"Symlink Movie");
    	for(FXint i=0; !filenamelist[i].empty(); i++){
			rootname="."+FXPath::stripExtension(FXPath::name(filenamelist[i]));
			// printf("rootname: %s\n",rootname.text());
  			imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
			// printf("imagename: %s\n",imagename.text());

			// upgrade image if renamed more than one movie file
  			FXImage *img=NULL;
  			FXImage *old=NULL;
			#ifdef FOX_16
  			 	img=new FXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			#endif
			#ifdef FOX_17
			  	img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			#endif
			// Perhaps failed
  			if(img){
    			FXFileStream stream;
    			// Load image
    			if(stream.open(imagename,FXStreamLoad)){
    				getApp()->beginWaitCursor();
    				img->loadPixels(stream);
    				stream.close();
   					// Create image
   					img->create();
   					img->scale(400,320,FXCLAMP(0,1,1));
   					// Set new image, deleting old
   					old=operationsdialog.getNewImage();
   					operationsdialog.setNewImage(img);	
   					delete old;
   					getApp()->endWaitCursor();
				}
    		}

      		operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      		operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));

      		if(!operationsdialog.execute()) break;
      			newname=operationsdialog.getNewName();
      		    if(!FXFile::symlink(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname))){
			    	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Lynking Movie","Unable to link File:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),newname.text())==MBOX_CLICKED_NO) break;
			   	}
      		    else if(!FXFile::symlink(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname))){
       				// recreate imageicon
        			rootname="."+FXPath::name(FXPath::stripExtension(newname));
        			createImageMovie(newname,rootname);

/*
					system("sleep 0.5s");
        			imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
					FXString newitemname=FXPath::name(newname);
 					FXint index=filelist->findItem(newitemname);
					previewMovie(imagename,index,imgw,imgh);
					filelist->updateItem(index);
*/
				}
   			}
    		delete [] filenamelist;
  		}
  return 1;
  }


// Copy file or directory
long FXMovieManager::onCmdFileCopy(FXObject*,FXSelector,void*){
	deselectMainDir();
	FXString rootname,imagename,newname;
  	FXString *filenamelist=getFilenames();

  	if(filenamelist){
    	OperationsDialog operationsdialog(this,"Copy Movie");
    	for(FXint i=0; !filenamelist[i].empty(); i++){
			rootname="."+FXPath::stripExtension(FXPath::name(filenamelist[i]));
			// printf("rootname: %s\n",rootname.text());
  			imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
			// printf("imagename: %s\n",imagename.text());

			// upgrade image if renamed more than one movie file
  			FXImage *img=NULL;
  			FXImage *old=NULL;
			#ifdef FOX_16
  			 	img=new FXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			#endif
			#ifdef FOX_17
			  	img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			#endif
			// Perhaps failed
  			if(img){
    			FXFileStream stream;
    			// Load image
    			if(stream.open(imagename,FXStreamLoad)){
    				getApp()->beginWaitCursor();
    				img->loadPixels(stream);
    				stream.close();
   					// Create image
   					img->create();
   					img->scale(400,320,FXCLAMP(0,1,1));
   					// Set new image, deleting old
   					old=operationsdialog.getNewImage();
   					operationsdialog.setNewImage(img);	
   					delete old;
   					getApp()->endWaitCursor();
				}
    		}

      		operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      		operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),"Copy_"+FXPath::name(filenamelist[i])));

      		if(!operationsdialog.execute()) break;
      			newname=operationsdialog.getNewName();
      		    if(!FXFile::copyFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname),FALSE)){
			    	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Copying Movie","Unable to copy File:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),newname.text())==MBOX_CLICKED_NO) break;
			   	}
      		    else if(!FXFile::copyFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname),TRUE)){
       				// recreate imageicon
        			rootname="."+FXPath::name(FXPath::stripExtension(newname));
        			createImageMovie(newname,rootname);
/*
					system("sleep 0.5s");
        			imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
					FXString newitemname=FXPath::name(newname);
 					FXint index=filelist->findItem(newitemname);
					previewMovie(imagename,index,imgw,imgh);
					filelist->updateItem(index);
*/
				}
   			}
    		delete [] filenamelist;
  		}
  return 1;
  }


// Rename movie file or directory
long FXMovieManager::onCmdFileRename(FXObject*,FXSelector,void*){
	deselectMainDir();
	FXString rootname,imagename,newname;
  	FXString *filenamelist=getFilenames();

  	if(filenamelist){
    	OperationsDialog operationsdialog(this,"Rename Movie");
    	for(FXint i=0; !filenamelist[i].empty(); i++){
			rootname="."+FXPath::stripExtension(FXPath::name(filenamelist[i]));
			// printf("rootname: %s\n",rootname.text());
  			imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
			// printf("imagename: %s\n",imagename.text());

			// upgrade image if renamed more than one movie file
  			FXImage *img=NULL;
  			FXImage *old=NULL;
			#ifdef FOX_16
  			 	img=new FXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			#endif
			#ifdef FOX_17
			  	img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			#endif
			// Perhaps failed
  			if(img){
    			FXFileStream stream;
    			// Load image
    			if(stream.open(imagename,FXStreamLoad)){
    				getApp()->beginWaitCursor();
    				img->loadPixels(stream);
    				stream.close();
   					// Create image
   					img->create();
   					img->scale(400,320,FXCLAMP(0,1,1));
   					// Set new image, deleting old
   					old=operationsdialog.getNewImage();
   					operationsdialog.setNewImage(img);	
   					delete old;
   					getApp()->endWaitCursor();
				}
    		}

      		operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      		operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));

      		if(!operationsdialog.execute()) break;
      			newname=operationsdialog.getNewName();
      		    if(!FXFile::moveFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname),FALSE)){
			    	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Renaming Movie","Unable to rename File:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),newname.text())==MBOX_CLICKED_NO) break;
			   	}
      		    else if(!FXFile::moveFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname),TRUE)){
       				// recreate imageicon
        			rootname="."+FXPath::name(FXPath::stripExtension(newname));
        			createImageMovie(newname,rootname);
/*
					system("sleep 0.5s");
        			imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";

					FXString newitemname=FXPath::name(newname);

 					FXint index_l=filelist->findItem(newname);
 					FXint index_s=filelist->findItem(newitemname);

					printf("+++++>newname: %s\n",newname.text());
					printf("+++++>newitemname: %s\n",newitemname.text());

					printf("----->index_long: %d\n",index_l);
					printf("----->index_short: %d\n",index_s);

					previewMovie(imagename,index_s,imgw,imgh);
					filelist->updateItem(index_s);
*/
				}
   			}
    		delete [] filenamelist;
  		}
  return 1;
  }


// deselect (..) directory
void FXMovieManager::deselectMainDir(){

  	for(FXint i=0; i<filelist->getNumItems(); i++){
    	if(filelist->isItemSelected(i)){
        	FXString file=filelist->getItemFilename(i);
			// prevent crash when renaming directory (..)
        	if(file=="..") {
				filelist->deselectItem(i);
				continue;
			}
		}
	}
}

// Delete file or directory in the file list
long FXMovieManager::onCmdFileDelete(FXObject*,FXSelector,void*){
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Movie","Are you sure YOU WANT TO DELETE these files?");
  if(answer==MBOX_CLICKED_YES){
    FXString filetoremove,file;
    for(FXint i=0; i<filelist->getNumItems(); i++){
      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
        filetoremove=FXPath::absolute(filelist->getDirectory(),file);
        FXTRACE((100,"filetoremove=%s\n",filetoremove.text()));
        if(!FXFile::removeFiles(filetoremove,TRUE)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Movie","Unable to delete movie: %s\nContinue with operation?",filetoremove.text())){
            break;
            }
          }
        }

      }
    }
  return 1;
  }


// Pop up mimetype dialog
long FXMovieManager::onCmdTerminal(FXObject*,FXSelector,void*){

  FXString executable="cd "+FXPath::enquote(getDirectory())+"; "+terminal+" &";
  system(executable.text());

  return 1;
  }


/****************************MIYME TYPES*********************************/

// Pop up mimetype dialog
long FXMovieManager::onCmdMimeType(FXObject*,FXSelector,void*){

    mimetype->show(PLACEMENT_OWNER);

  return 1;
  }


// associated Command
long FXMovieManager::onCmdOpen(FXObject*,FXSelector,void*){
  FXint index=filelist->getCurrentItem();
  if(index>=0){

    // If directory, open the directory
    if(filelist->isItemDirectory(index)){
      FXString directory=filelist->getItemPathname(index);
      FXTRACE((100,"directory=%s\n",directory.text()));
      filelist->setDirectory(directory);
      dirlist->setDirectory(directory);
      }

    // If regular file return as the selected file
    else if(filelist->isItemFile(index)){

      FXFileAssoc *fileassoc=filelist->getItemAssoc(index);
      if(fileassoc){
        if(fileassoc->command.text()){
          FXString command=FXString::value(fileassoc->command.text());
	  FXString runcommand = "cd "+FXPath::enquote(getDirectory())+"; "+command+" "+filelist->getItemFilename(index)+" &";
          FXTRACE((100,"system(%s)\n",command.text()));
	      // printf("runcommand: %s\n", runcommand.text()); 
          system(runcommand.text());
          }
        else{
          FXMessageBox::information(this,MBOX_OK,"Unknown Command","No command has been defined for this file: %s",filelist->getItemFilename(index).text());
          }
        }
      else{
        FXMessageBox::information(this,MBOX_OK,"Unknown Mime Type","No Association has been set for this file: %s",filelist->getItemFilename(index).text());
        }
      }

      
  }
  return 1;
}


// Open with program
long FXMovieManager::onCmdOpenWith(FXObject*,FXSelector,void*){
  FXString command=getApp()->reg().readStringEntry("SETTINGS","command","mplayer");
  FXString filename=filelist->getCurrentFile();

  if(FXInputDialog::getString(command,this,"Open Movie File","Open " + FXPath::name(filename) + " with:")){
    getApp()->reg().writeStringEntry("SETTINGS","command",command.text());
    command=command+" "+filename+" &";
    // printf("command: %s\n", command.text()); 
    system(command.text());
    }
  return 1;
}


long FXMovieManager::onUpdItemFound(FXObject* sender,FXSelector,void*){

  sender->handle(this,filelist->getCurrentFile().empty()?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),NULL);

  return 1;
}


/****************************PROPERTIES**********************************/

// Pop up properties dialog
long FXMovieManager::onCmdProperties(FXObject*,FXSelector,void*){

  FXString info="/tmp/.fxmm/00000001.txt";
  system ("test -e /tmp/.fxmm/00000001.txt && rm /tmp/.fxmm/00000001.txt");

  FXString filename=filelist->getCurrentFile();
  createInfoMovie(filename);
  system("sleep 0.5s");

  FXchar *text;
  FXint size;

  FXFile fvideo(info,FXFile::Reading);
  size=fvideo.size();

#ifdef FOX_16
  if(!FXMALLOC(&text,FXchar,size)){
#endif
#ifdef FOX_17
  if(allocElms(text,size)){
#endif

    fvideo.readBlock(text,size);
    FXString block = text;

    FXRex rexvideo1("VIDEO:",0);
    FXint begv1,endv1;
    FXRex rexvideo2("kbyte",0);
    FXint begv2,endv2;
    if(rexvideo1.match(text,&begv1,&endv1)){
	if(rexvideo2.match(text,&begv2,&endv2)){
	FXint lenv=endv2-endv1+3;
    	FXString seltextv=block.mid(endv1,lenv);
    	grepvideo=seltextv;
        }
    }
    else {grepvideo="NOT FOUND";}

    FXRex rexaudio1("AUDIO:",0);
    FXint bega1,enda1;
    FXRex rexaudio2("->",0);
    FXint bega2,enda2;
    if(rexaudio1.match(text,&bega1,&enda1)){
	if(rexaudio2.match(text,&bega2,&enda2)){
	FXint lena=enda2-enda1+7;
    	FXString seltexta=block.mid(enda1,lena);
    	grepaudio=seltexta;
        }
    }
    else {grepaudio="NOT FOUND";}

  }
  fvideo.close();

#ifdef FOX_16
  FXFREE(&text);
#endif
#ifdef FOX_17
  freeElms(text);
#endif

  properties->show(PLACEMENT_OWNER);

  return 1;
  }


// Update create time
long FXMovieManager::onUpdCreateTime(FXObject* sender,FXSelector,void*){
#ifdef FOX_16
  FXString time=FXSystem::time(FXStat::created(filelist->getCurrentFile()));
#endif
#ifdef FOX_17
  FXString time=FXSystem::localTime(FXStat::created(filelist->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update modified time
long FXMovieManager::onUpdModifyTime(FXObject* sender,FXSelector,void*){
#ifdef FOX_16
  FXString time=FXSystem::time(FXStat::modified(filelist->getCurrentFile()));
#endif
#ifdef FOX_17
  FXString time=FXSystem::localTime(FXStat::modified(filelist->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update access time
long FXMovieManager::onUpdAccessTime(FXObject* sender,FXSelector,void*){
#ifdef FOX_16
  FXString time=FXSystem::time(FXStat::accessed(filelist->getCurrentFile()));
#endif
#ifdef FOX_17
  FXString time=FXSystem::localTime(FXStat::accessed(filelist->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update file location
long FXMovieManager::onUpdFileLocation(FXObject* sender,FXSelector,void*){
  FXString string=filelist->getCurrentFile();
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
  return 1;
  }

// Update file size
long FXMovieManager::onUpdFileSize(FXObject* sender,FXSelector,void*){
  FXString size;
#ifdef FOX_16
  size=FXStringVal(FXStat::size(filelist->getCurrentFile()));
#endif
#ifdef FOX_17
  size.fromInt(FXStat::size(filelist->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&size);
  return 1;
  }

// Update file type
long FXMovieManager::onUpdFileType(FXObject* sender,FXSelector,void*){
  FXString filename=filelist->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString type;
  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    type="Folder";
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    type="Binary";
    }
  else{
    fileassoc=associations->findFileBinding(filename.text());
    type="File..";
    }
      
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&type);
	
  return 1;
  }
  
// Update file mimetype
long FXMovieManager::onUpdFileMimeType(FXObject* sender,FXSelector,void*){

  FXString filename=filelist->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString mimetype;
  if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    }
  if(fileassoc){    
  if(fileassoc->mimetype.text()){
          mimetype=FXString::value(fileassoc->mimetype.text());
  }
  }
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&mimetype);
	
  return 1;

  }

  // Update file command
long FXMovieManager::onUpdFileCommand(FXObject* sender,FXSelector,void*){

  FXString filename=filelist->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString command;
  if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    }
  if(fileassoc){    
  if(fileassoc->command.text()){
          command=FXString::value(fileassoc->command.text());
  }
  }
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&command);
	
  return 1;

  }
  
// Update file desc
long FXMovieManager::onUpdFileDesc(FXObject* sender,FXSelector,void*){
  FXString filename=filelist->getCurrentFile();
  FXLabel *label=(FXLabel*)sender;
  FXFileAssoc *fileassoc=NULL;
  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    }
  else{
    fileassoc=associations->findFileBinding(filename.text());
    }
  label->setText(FXPath::name(filename));
  if(fileassoc){
    if(fileassoc->bigicon) fileassoc->bigicon->create();
    label->setIcon(fileassoc->bigicon);
    }
  else{
    label->setIcon(NULL); // need a default suggestion here
    }
  return 1;
  }

// find video aspect
long FXMovieManager::onUpdMovieAspect(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepvideo);
  return 1;
  }

// find audio format
long FXMovieManager::onUpdAudioFormat(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepaudio);
  return 1;
  }


/****************************FILE BUTTONS**********************************/

// Play the movies from the file list
long FXMovieManager::onCmdFilePlay(FXObject*,FXSelector,void*){

   system ("test -p /tmp/.fxmm/fifo && rm /tmp/.fxmm/fifo");
   system ("test -p /tmp/.fxmm/fifo || mkfifo /tmp/.fxmm/fifo");

   FXString filetoplay,file,playlist;

    for(FXint i=0; i<filelist->getNumItems(); i++){
      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
        filetoplay=FXPath::absolute(filelist->getDirectory(),file);
		playlist=playlist+" "+filetoplay;
      }
    }

	FXString i_command = s_command + s_video + s_size + s_full + s_loop;
    s_play = i_command + playlist + " &";
	system("killall mplayer");
    system(s_play.text());

    int fd;
    // Spawn child
    if(fork()==0){
      // Close on exec of file descriptor
      fcntl(fd,F_SETFD,TRUE);
      // Start command and pass it the playlist
      execlp(i_command.text(),i_command.text(),playlist.text(),NULL);
      // In case we failed to execute the command
      ::exit(0);
      }

    isrunning = TRUE;
    playlist="";
    s_play="";
  return 1;
  }

// Stop player
long FXMovieManager::onCmdFileStop(FXObject *,FXSelector,void *) {
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "quit 1\n");
		fclose(f);
		isrunning=FALSE;
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}

// Pause playing the movie from the file list
long FXMovieManager::onCmdFilePause(FXObject*,FXSelector,void *){
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "pause\n");
		fclose(f);
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
  }

// Enable sender when items have been selected
long FXMovieManager::onUpdSelectedFile(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist->getNumItems(); i++){
    	if(filelist->isItemSelected(i)){
       		file=filelist->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist->isItemDirectory(i)) return 1;
    	}
	}

    sender->handle(this,getNumFilenames()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
    return 1;
}


/***************************MOVIE PREVIEW*******************************/

// Thumbnails creation
long FXMovieManager::onCmdFilePreview(FXObject*,FXSelector,void*){
    FXString filetoplay,file,rootname,imagename,infoname;

    progressbar->setProgress(0);
    progressbar->setTotal(filelist->getNumItems());
    progressbar->setBarColor(FXRGB(0,0,250));

    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
      	file=filelist->getItemFilename(i);
      	if(file=="..") continue;
		if(filelist->isItemDirectory(i)) continue;
	      
        filetoplay=FXPath::absolute(filelist->getDirectory(),file);
        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";

    	FXFile truefile;
		FXbool istruefile = truefile.open(imagename);
	  	if(!istruefile){
	    	createImageMovie(filetoplay,rootname);
	  	}
      }
    }

    system("sleep 2s");

    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(250,0,0));


    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
		if(filelist->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
		previewMovie(imagename, i, imgw, imgh);
      }
    }	
    return 1;
}


// Force tumbnails recreation 
long FXMovieManager::onCmdForceFilePreview(FXObject*,FXSelector,void*){
    FXString filetoplay,file,rootname,imagename;

    progressbar->setProgress(0);
    progressbar->setTotal(filelist->getNumItems());
    progressbar->setBarColor(FXRGB(0,0,250));

    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
		if(filelist->isItemDirectory(i)) continue;
	      
        filetoplay=FXPath::absolute(filelist->getDirectory(),file);
        rootname="."+FXPath::stripExtension(file);

        createImageMovie(filetoplay,rootname);

      }
   }

    system("sleep 2s");

    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(250,0,0));


    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
		if(filelist->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
		previewMovie(imagename, i, imgw, imgh);
      }
   }
   return 1;
}


// Resize tumbnails preview 
long FXMovieManager::onCmdWideScreen(FXObject*,FXSelector,void*){

	if(widescreen==TRUE){
		widescreen=FALSE;
		imgw=80; imgh=64;
	} 
	else if(widescreen==FALSE){
		widescreen=TRUE;
		imgw=120; imgh=64;
	}
	else {
		widescreen=FALSE;
		imgw=80; imgh=64;
	}	
   return 1;
}


// Resize tumbnails preview 
long FXMovieManager::onCmdIncFilePreview(FXObject*,FXSelector,void*){
    FXString file,rootname,imagename;

	if(widescreen==TRUE){
 		imgw=imgw+60;
    	imgh=imgh+32;
	} 
	else if(widescreen==FALSE){
 		imgw=imgw+40;
    	imgh=imgh+32;
	}
	else {
  		imgw=imgw+40;
    	imgh=imgh+32;
	}	

    for(FXint i=0; i<filelist->getNumItems(); i++){

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
		if(filelist->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
		previewMovie(imagename, i, imgw, imgh);
      }
    }	
   return 1;
}


// Resize tumbnails preview 
long FXMovieManager::onCmdDecFilePreview(FXObject*,FXSelector,void*){
    FXString file,rootname,imagename;

	if(widescreen==TRUE){
 		imgw=imgw-60;
    	imgh=imgh-32;
	} 
	else if(widescreen==FALSE){
 		imgw=imgw-40;
    	imgh=imgh-32;
	}
	else {
  		imgw=imgw-40;
    	imgh=imgh-32;
	}

    for(FXint i=0; i<filelist->getNumItems(); i++){

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
		if(filelist->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
		previewMovie(imagename, i, imgw, imgh);
      }
    }	
   return 1;
}


// clear all preview and all hidden directories
long FXMovieManager::onCmdClearPreview(FXObject*,FXSelector,void*){
    FXString dirname,executable;
    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(0,250,0));

    FXbool state=filelist->showHiddenFiles();
    if(state==FALSE){
		filelist->showHiddenFiles(TRUE);
	}
    if(filelist->showHiddenFiles()==TRUE){
    	for(FXint i=0; i<filelist->getNumItems(); i++){
       		progressbar->increment(i);
       		if(filelist->isItemDirectory(i)){
       	  		dirname=filelist->getItemFilename(i);
          		if(dirname=="..") continue;
	  			// use of FXRex
    	  		FXRex rexdir("00000001",0);
          		FXint begd,endd;
          		if(rexdir.match(dirname,&begd,&endd)){
             		executable="cd "+FXPath::enquote(getDirectory())+"; rm -r "+dirname+" &";
             		system(executable.text());
	  			}
			}
     	}
  	}
  filelist->showHiddenFiles(state);
  return 1;
  }


FXbool FXMovieManager::createImageMovie(const FXString& filetoplay,const FXString& rootname){

	FXfloat seekvalue=seekspinner->getValue();
	FXString seekstring	= "-ss " + (FXString::value(seekvalue,2)) + " ";

	FXString command="mplayer "+seekstring+"-frames 1 -nocache -ao null -vo jpeg:subdirs="+rootname+" "+filetoplay+" &";
	FXString executable="cd "+FXPath::enquote(getDirectory())+"; "+command;
	// printf("executable: %s\n", executable.text());
        system(executable.text());
 
        return TRUE;
 }


FXbool FXMovieManager::createInfoMovie(const FXString& filename){

    FXString infoname="/tmp/.fxmm/00000001.txt";
	FXString propcommand="mplayer -frames 0 -nocache -ao null -vo null "+filename+" &> "+infoname+" &";
	// printf("propcommand: %s\n", propcommand.text());
	system(propcommand.text());

        return TRUE;
 }


// Load imagemovie to icon for preview
FXbool FXMovieManager::previewMovie(const FXString& filename, FXint i, FXint w, FXint h){

    FXString imagename=filename;
#ifdef FOX_16
    FXIcon *tempicon=NULL;
    tempicon=new FXIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);
#endif
#ifdef FOX_17
    FXJPGIcon *tempicon=NULL;
    tempicon=new FXJPGIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);
#endif

    if (tempicon){
   		FXFileStream stream;
   		if (stream.open(imagename,FXStreamLoad)){
			getApp()->beginWaitCursor();
			tempicon->loadPixels(stream);
			stream.close();
			tempicon->scale(w,h,75); 
   	 		tempicon->create();
			//freeImageMemory(i);
			filelist->setItemBigIcon(i,tempicon);
			getApp()->endWaitCursor();
			return TRUE;
		}
    }
    return FALSE;
}


FXbool FXMovieManager::freeImageMemory(FXint i) {
    FXIcon *oldicon=NULL;
	FXString file;
    file=filelist->getItemFilename(i);
    if(file=="..") return FALSE;
  	if(filelist->getItemBigIcon(i)){
		oldicon=filelist->getItemBigIcon(i);
		filelist->setItemBigIcon(i,NULL);
		delete oldicon;  // delete the current icon
   	}
	return TRUE;
}


/*********************************ROUTINES**********************************/


// Get number of selected filenames, not including "." and ".."
FXint FXMovieManager::getNumFilenames() const {
  register FXint num=0;
  register FXint i;
  if(filelist->getNumItems()){
    for(i=0; i<filelist->getNumItems(); i++){
#ifdef FOX_16
      if(filelist->isItemSelected(i) && filelist->getItemFilename(i)!=".." && filelist->getItemFilename(i)!=".") num++;
#endif
#ifdef FOX_17
      if(filelist->isItemSelected(i) && !filelist->isItemNavigational(i)) num++;
#endif
      }
    }
  return num;
  }


// Return selected filenames, not including "." and ".."
FXString* FXMovieManager::getFilenames() const {
  register FXint num=getNumFilenames();
  register FXString *files=NULL;
  register FXint i,n;
  if(0<num){
    files=new FXString [num+1];
    for(i=n=0; i<filelist->getNumItems(); i++){
#ifdef FOX_16
      if(filelist->isItemSelected(i) && filelist->getItemFilename(i)!=".." && filelist->getItemFilename(i)!="."){
#endif
#ifdef FOX_17
      if(filelist->isItemSelected(i) && !filelist->isItemNavigational(i)){
#endif
	files[n++]=filelist->getItemPathname(i);
	}
      }
    files[n]=FXString::null;
    }
  return files;
  }


// Get current directory
FXString FXMovieManager::getDirectory() const {
  return filelist->getDirectory();
  }


// EOF
